DecoderStatus

Enum DecoderStatus 

pub enum DecoderStatus {
    NeedsMore,
    Ready,
}
Indicates whether a decoder needs more data or is ready to finalize.

This is returned from the Decoder::push_bytes method to indicate whether the decoder should continue accumulating data or is ready to produce the decoded value with Decoder::end.

Variants



NeedsMore

The decoder needs more data to complete decoding.

Continue pushing byte slices with Decoder::push_bytes until this status changes to Ready.



Ready

The decoder has accumulated sufficient data and is ready to finalize.

Call Decoder::end to complete the decoding process and obtain the final result.

Implementations

Source

impl DecoderStatus

pub fn needs_more(&self) -> bool

Returns true if the decoder needs more data to continue.

pub fn is_ready(&self) -> bool

Returns true if ready to produce decoded value with Decoder::end.