EncoderStatus

Enum EncoderStatus 

pub enum EncoderStatus {
    HasMore,
    Finished,
}
Indicates whether the encoder still has bytes available or it is finished.

This is returned from the Encoder::advance method to indicate whether encoding should stop or continue.

Variants



HasMore

The encoder has more bytes available (not yet finished).

The current_chunk method should be called to obtain them and write them out after which advance should be called again to obtain the next chunk (if any).



Finished

The encoding has ended, no more bytes are available.

No encoder methods (other than drop) may be called after this variant is returned.

Implementations

Source

impl EncoderStatus

pub fn has_more(&self) -> bool

Returns true if self is HasMore, false otherwise.

pub fn has_finished(&self) -> bool

Returns true if self is Finished, false otherwise.