Module error

Module error 

Error types for the whole crate.

All error types are publicly available at the crate root.

Structs

ByteVecDecoderError
The error returned by the ByteVecDecoder.
CompactSizeDecoderError
An error consensus decoding a compact size encoded integer.
LengthPrefixExceedsMaxError
The error returned when a compact size value exceeds a configured limit.
UnconsumedError
Bytes remained unconsumed after completing decoding.
UnexpectedEofError
Not enough bytes given to decoder.
VecDecoderError
The error returned by the VecDecoder.

Enums

DecodeError
An error that can occur when decoding from a byte slice.
Decoder2Error
Error type for Decoder2.
Decoder3Error
Error type for Decoder3.
Decoder4Error
Error type for Decoder4.
Decoder6Error
Error type for Decoder6.
ReadError
An error that can occur when reading and decoding from a buffered reader.