pub enum DecodeError<Err> {
Parse(Err),
Unconsumed(UnconsumedError),
}Expand description
An error that can occur when decoding from a byte slice.
Variants
Parse(Err)
Provided slice failed to correctly decode as a type.
Unconsumed(UnconsumedError)
Bytes remained unconsumed after completing decoding.