decode_from_hex

Function decode_from_hex 

pub fn decode_from_hex<T: Decode>(
    hex: &str,
) -> Result<T, FromHexError<<T::Decoder as Decoder>::Error>>
Decodes an object from a hex string without heap allocations.

Errors

FromHexError if the string has an odd number of characters, any character is not a valid hex digit, or if decoding the type fails, including if bytes remain unconsumed after the decoder completes.