ArrayRefEncoder

Struct ArrayRefEncoder 

pub struct ArrayRefEncoder<'e, const N: usize> { /* private fields */ }
An encoder for a reference to an array.

This encoder borrows the array instead of taking ownership, avoiding a copy when the array is already available by reference (e.g., as a struct field).

Implementations

Source

impl<'e, const N: usize> ArrayRefEncoder<'e, N>

pub const fn without_length_prefix(arr: &'e [u8; N]) -> Self

Constructs an encoder which encodes the array reference with no length prefix.