SliceEncoder

Struct SliceEncoder 

pub struct SliceEncoder<'e, T: Encodable> { /* private fields */ }
An encoder for a list of encodable types.

Implementations

Source

impl<'e, T: Encodable> SliceEncoder<'e, T>

pub fn without_length_prefix(sl: &'e [T]) -> Self

Constructs an encoder which encodes the slice without adding the length prefix.

To encode with a length prefix consider using Encoder2.

E.g, Encoder2<CompactSizeEncoder, SliceEncoder<'e, Foo>>.