pub struct VecDecoderWith<D: Decoder + Default> { /* private fields */ }Expand description
A decoder for a compact sized length-prefixed vector of items, generic over the item decoder type.
When the item count is known from context rather than a length prefix, use
ExactVecDecoderWith instead.
Implementations
Sourceimpl<D: Decoder + Default> VecDecoderWith<D>
impl<D: Decoder + Default> VecDecoderWith<D>
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Constructs a new decoder with the default limit of 4,000,000 elements.
Sourcepub const fn new_with_limit(limit: usize) -> Self
pub const fn new_with_limit(limit: usize) -> Self
Constructs a new decoder with a custom element limit.