pub enum EncoderStatus {
HasMore,
Finished,
}Expand description
Indicates whether the encoder still has bytes available or it is finished.
This is returned from the Encoder::advance method to indicate whether encoding should stop
or continue.
Variants
HasMore
The encoder has more bytes available (not yet finished).
The current_chunk method should be called to obtain them and
write them out after which advance should be called again to obtain
the next chunk (if any).
Finished
The encoding has ended, no more bytes are available.
No encoder methods (other than drop) may be called after this variant is returned.
Implementations
Sourceimpl EncoderStatus
impl EncoderStatus